# Test suite
pysilfont has a pytest-based test suite.

### install the test framework bits:
```
python3 -m pip install pytest
```

## set up the folders:
```
python3 tests/setuptestdata.py
```

## run the test suite:
```
pytest
```
